pub struct AuthInfoBuilder { /* private fields */ }Expand description
Builder for constructing AuthInfo instances
This builder provides a fluent interface for creating AuthInfo objects.
Implementations
Sourceimpl AuthInfoBuilder
impl AuthInfoBuilder
Sourcepub fn signature(self, signature: impl Into<String>) -> Self
pub fn signature(self, signature: impl Into<String>) -> Self
Set the signature (base64-encoded signature bytes)
Sourcepub fn pubkey_hint(self, pubkey: &PublicKey) -> Self
pub fn pubkey_hint(self, pubkey: &PublicKey) -> Self
Set a pubkey hint
Sourcepub fn global_hint(self, actual_pubkey: &PublicKey) -> Self
pub fn global_hint(self, actual_pubkey: &PublicKey) -> Self
Set a global permission hint with actual signer pubkey