pub struct DelegationStep {
pub tree: String,
pub tips: Vec<ID>,
}Expand description
Step in a delegation path
References a delegated tree by its root entry ID. The final signer hint is stored in the parent SigKey, not in the DelegationStep.
Fields
tree: StringRoot entry ID of the delegated tree (used to look up the delegation in AuthSettings)
tips: Vec<ID>Tips of the delegated tree at time of signing