pub struct SigInfoBuilder { /* private fields */ }Expand description
Builder for constructing SigInfo instances
This builder provides a fluent interface for creating SigInfo objects.
Implementations
Sourceimpl SigInfoBuilder
impl SigInfoBuilder
Sourcepub fn sig(self, sig: impl Into<String>) -> Self
pub fn sig(self, sig: impl Into<String>) -> Self
Set the signature (base64-encoded signature bytes)
Sourcepub fn pubkey_hint(self, pubkey: &PublicKey) -> Self
pub fn pubkey_hint(self, pubkey: &PublicKey) -> Self
Set a pubkey hint
Sourcepub fn global_hint(self, actual_pubkey: &PublicKey) -> Self
pub fn global_hint(self, actual_pubkey: &PublicKey) -> Self
Set a global permission hint with actual signer pubkey