pub enum KeyStatus {
Active,
Revoked,
}Expand description
Status of an authentication key
Variants
Active
Key is active and can create new entries
Revoked
Key is revoked - cannot create new entries, but historical entries are preserved Content of revoked entries is preserved during merges, but cannot be parents of new entries