pub struct DelegationResolver;Expand description
Delegation resolver for handling complex delegation paths
Implementations
Sourceimpl DelegationResolver
impl DelegationResolver
Sourcepub async fn resolve_delegation_path_with_depth(
&mut self,
steps: &[DelegationStep],
final_hint: &KeyHint,
auth_settings: &AuthSettings,
instance: &Instance,
_depth: usize,
) -> Result<Vec<ResolvedAuth>>
pub async fn resolve_delegation_path_with_depth( &mut self, steps: &[DelegationStep], final_hint: &KeyHint, auth_settings: &AuthSettings, instance: &Instance, _depth: usize, ) -> Result<Vec<ResolvedAuth>>
Resolve delegation path using flat list structure
This iteratively processes each step in the delegation path, applying permission clamping at each level. The final hint is resolved in the last delegated tree’s auth settings.
Returns all matching ResolvedAuth entries. For name hints that match multiple keys at the final step, all matches are returned with the same permission clamping applied to each.