pub async fn initialize(backend: &SqlxBackend) -> Result<()>Expand description
Initialize the database schema.
Creates tables and indexes if they don’t exist, and handles migrations if the schema version has changed.
pub async fn initialize(backend: &SqlxBackend) -> Result<()>Initialize the database schema.
Creates tables and indexes if they don’t exist, and handles migrations if the schema version has changed.