pub enum StoreStateLifecycle {
Derived,
Authoritative,
Staging,
}Expand description
Lifecycle of stored Store state.
Derived state is a disposable cached materialization of historical Entries. Authoritative state is durable current state. Staging is a private unpublished build and is never visible to record reads.
Variants