pub struct ProjectionDescriptor {
pub name: String,
pub version: u32,
}Expand description
Identifies a Store’s cached record format.
Store implementations change the version when the encoding becomes incompatible. Backends compare this value opaquely when resolving cached state.
Fields
name: Stringversion: u32Trait Implementations
Sourceimpl Clone for ProjectionDescriptor
impl Clone for ProjectionDescriptor
Sourcefn clone(&self) -> ProjectionDescriptor
fn clone(&self) -> ProjectionDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectionDescriptor
impl Debug for ProjectionDescriptor
Sourceimpl<'de> Deserialize<'de> for ProjectionDescriptor
impl<'de> Deserialize<'de> for ProjectionDescriptor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ProjectionDescriptor
impl Hash for ProjectionDescriptor
Sourceimpl PartialEq for ProjectionDescriptor
impl PartialEq for ProjectionDescriptor
Sourcefn eq(&self, other: &ProjectionDescriptor) -> bool
fn eq(&self, other: &ProjectionDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProjectionDescriptor
impl Serialize for ProjectionDescriptor
impl Eq for ProjectionDescriptor
impl StructuralPartialEq for ProjectionDescriptor