pub struct RecordPage {
pub records: Vec<(Vec<u8>, Vec<u8>)>,
pub next: Option<Vec<u8>>,
}Expand description
One bounded ordered scan page. next is the last returned key and must be
supplied as the exclusive continuation on the next request.
Fields
records: Vec<(Vec<u8>, Vec<u8>)>next: Option<Vec<u8>>Trait Implementations
Sourceimpl Clone for RecordPage
impl Clone for RecordPage
Sourcefn clone(&self) -> RecordPage
fn clone(&self) -> RecordPage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecordPage
impl Debug for RecordPage
Sourceimpl Default for RecordPage
impl Default for RecordPage
Sourcefn default() -> RecordPage
fn default() -> RecordPage
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RecordPage
impl<'de> Deserialize<'de> for RecordPage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RecordPage
impl PartialEq for RecordPage
Sourcefn eq(&self, other: &RecordPage) -> bool
fn eq(&self, other: &RecordPage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RecordPage
impl Serialize for RecordPage
impl Eq for RecordPage
impl StructuralPartialEq for RecordPage