pub struct Registry { /* private fields */ }Expand description
A registry that wraps a DocStore and provides specialized methods for managing typed entries with metadata.
Registry provides a clean abstraction for storing entries with
{ type, config } structure. Used for:
_indexsubtree: Store type metadata in databasestransportssubtree: Transport configuration in sync
Implementations
Sourceimpl Registry
impl Registry
Sourcepub async fn set_entry(
&self,
name: impl AsRef<str>,
type_id: impl Into<String>,
config: Doc,
) -> Result<()>
pub async fn set_entry( &self, name: impl AsRef<str>, type_id: impl Into<String>, config: Doc, ) -> Result<()>
Sourcepub async fn get_subtree_settings(
&self,
name: impl AsRef<str>,
) -> Result<SubtreeSettings>
pub async fn get_subtree_settings( &self, name: impl AsRef<str>, ) -> Result<SubtreeSettings>
Sourcepub async fn set_subtree_settings(
&self,
name: impl AsRef<str>,
settings: SubtreeSettings,
) -> Result<()>
pub async fn set_subtree_settings( &self, name: impl AsRef<str>, settings: SubtreeSettings, ) -> Result<()>
Update the settings for a registered subtree.
The subtree must already be registered (via set_entry). This method
only updates the settings portion, preserving the type_id and config.
Arguments
name- The name of the subtreesettings- The new settings to apply
Returns
Result indicating success or failure. Returns an error if the subtree is not registered.