Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

SyncCommand

Enum SyncCommand 

pub enum SyncCommand {
    SendEntries {
        peer: PeerId,
        entries: Vec<Entry>,
    },
    SyncWithPeer {
        peer: PeerId,
    },
    Shutdown,
    AddTransport {
        name: String,
        transport: Box<dyn SyncTransport>,
        response: Sender<Result<()>>,
    },
    StartServer {
        name: Option<String>,
        response: Sender<Result<()>>,
    },
    StopServer {
        name: Option<String>,
        response: Sender<Result<()>>,
    },
    GetServerAddress {
        name: String,
        response: Sender<Result<String>>,
    },
    GetAllServerAddresses {
        response: Sender<Result<Vec<(String, String)>>>,
    },
    ConnectToPeer {
        address: Address,
        response: Sender<Result<PublicKey>>,
    },
    SendRequest {
        address: Address,
        request: Box<SyncRequest>,
        response: Sender<Result<SyncResponse>>,
    },
    Flush {
        response: Sender<Result<()>>,
    },
}
Commands that can be sent to the background sync engine

Variants



SendEntries

Send entries to a specific peer

Fields

peer: PeerId
entries: Vec<Entry>


SyncWithPeer

Trigger immediate sync with a peer

Fields

peer: PeerId


Shutdown

Shutdown the background engine



AddTransport

Add a named transport to the transport manager

Fields

name: String
transport: Box<dyn SyncTransport>
response: Sender<Result<()>>


StartServer

Start the sync server on specified or all transports

Fields

name: Option<String>

Transport name to start, or None for all transports

response: Sender<Result<()>>


StopServer

Stop the sync server on specified or all transports

Fields

name: Option<String>

Transport name to stop, or None for all transports

response: Sender<Result<()>>


GetServerAddress

Get the server’s listening address for a specific transport

Fields

name: String
response: Sender<Result<String>>


GetAllServerAddresses

Get all server addresses for running servers

Fields

response: Sender<Result<Vec<(String, String)>>>


ConnectToPeer

Connect to a peer and perform handshake

Fields

address: Address
response: Sender<Result<PublicKey>>


SendRequest

Send a sync request and get response

Fields

address: Address
request: Box<SyncRequest>
response: Sender<Result<SyncResponse>>


Flush

Flush: process all queued entries and retry queue, then respond.

Fields

response: Sender<Result<()>>