pub struct BackgroundSync { /* private fields */ }Expand description
Background sync engine that owns all sync state and handles operations
Implementations
Sourceimpl BackgroundSync
impl BackgroundSync
Sourcepub fn start(
instance: Instance,
sync_tree_id: ID,
queue: Arc<SyncQueue>,
peer_state: Arc<PeerStates>,
) -> Sender<SyncCommand>
pub fn start( instance: Instance, sync_tree_id: ID, queue: Arc<SyncQueue>, peer_state: Arc<PeerStates>, ) -> Sender<SyncCommand>
Start the background sync engine and return a command sender.
The engine starts with no transports registered. Use AddTransport
commands to add transports after starting.