pub struct SyncHandle { /* private fields */ }Expand description
Handle for tracking sync status with a specific peer.
Returned by Sync::register_sync_peer().
Implementations
Sourceimpl SyncHandle
impl SyncHandle
Sourcepub async fn status(&self) -> Result<SyncStatus>
pub async fn status(&self) -> Result<SyncStatus>
Get the current sync status.
Sourcepub async fn add_address(&self, address: Address) -> Result<()>
pub async fn add_address(&self, address: Address) -> Result<()>
Add another address hint for this peer.
Sourcepub async fn wait_for_initial_sync(&self) -> Result<()>
pub async fn wait_for_initial_sync(&self) -> Result<()>
Block until initial sync completes (has local data).
This is a convenience method for backwards compatibility. The sync happens in the background, this just polls until data arrives.
Sourcepub fn peer_pubkey(&self) -> &PublicKey
pub fn peer_pubkey(&self) -> &PublicKey
Get the peer public key.