pub struct TrackedDatabase {
pub database_id: ID,
pub key_id: PublicKey,
pub sync_settings: SyncSettings,
}Expand description
A database tracked by a user.
Stored in the user’s private database “databases” Table. Records which databases the user has added to their list, along with which key to use and sync preferences.
Fields
database_id: IDDatabase ID
key_id: PublicKeyWhich user key to use for this database
sync_settings: SyncSettingsSync preferences for this database