Struct BlockRange
pub struct BlockRange {
pub id: ID,
pub len: u32,
}Expand description
Describes a consecutive range of updates (identified by their IDs).
Fields
id: IDID of the first update stored within current BlockRange bounds.
len: u32Number of splittable updates stored within this BlockRange.
Implementations
impl BlockRange
impl BlockRange
pub fn new(id: ID, len: u32) -> BlockRange
pub fn last_id(&self) -> ID
pub fn last_id(&self) -> ID
Returns an ID of the last update fitting into the bounds of current BlockRange
pub fn slice(&self, offset: u32) -> BlockRange
pub fn slice(&self, offset: u32) -> BlockRange
Returns a slice of a current BlockRange, which starts at a given offset (relative to current range).
Example:
use yrs::block::BlockRange;
use yrs::ID;
let a = BlockRange::new(ID::new(1, 2), 8); // range of clocks [2..10)
let b = a.slice(3); // range of clocks [5..10)
assert_eq!(b.id, ID::new(1, 5));
assert_eq!(b.last_id(), ID::new(1, 10));pub fn contains(&self, id: &ID) -> bool
pub fn contains(&self, id: &ID) -> bool
Checks if provided id fits inside of boundaries defined by current BlockRange.