Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

Item

Struct Item 

pub struct Item { /* private fields */ }
Block defines a range of consecutive updates performed by the same peer. While individual updates are always uniquely defined by their corresponding IDs, they may contain a lot of additional metadata. Block representation here is crucial, since it optimizes memory usage, available when multiple updates have been performed one after another (eg. when user is writing a sentence, individual key strokes are independent updates but they can be compresses into a single block containing an entire sentence for as long as another piece of data is not being inserted in the middle it).

Implementations



impl Item

pub fn encode<E>(&self, encoder: &mut E)
where E: Encoder,

pub fn id(&self) -> &ID

Returns a unique identifier of a first update contained by a current Item.



impl Item

pub fn contains(&self, id: &ID) -> bool

Checks if provided id fits inside of updates defined within bounds of current Item.

pub fn is_deleted(&self) -> bool

Checks if current item is marked as deleted (tombstoned). Yrs uses soft item deletion mechanism, which means that deleted values are not physically erased from memory, but just marked as deleted.

pub fn is_countable(&self) -> bool

Checks if item content can be considered countable. Countable elements can be split and joined together.

pub fn len(&self) -> u32

Returns a length of a block. For most situation it works like Item::content_len with a difference to a [Text]/[XmlText] contents - in order to achieve compatibility with Yjs we need to calculate string length in terms of UTF-16 character encoding. However depending on used [Encoding] scheme we may calculate string length/offsets differently.

pub fn content_len(&self, kind: OffsetKind) -> u32

pub fn last_id(&self) -> ID

Returns an ID of the last element that can be considered a part of this item.

pub fn info(&self) -> u8