Struct Unused
#[repr(transparent)]pub struct Unused;Expand description
Empty type marker, which can be used by a Prelim trait implementations when no integrated value should be returned after prelim type has been integrated as a result of insertion.