Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

ClientID

Type Alias ClientID 

pub type ClientID = u64;
Globally unique client identifier. No two active peers are allowed to share the same ClientID. If that happens, following updates may cause document store to be corrupted and desync in a result.