Struct Options
pub struct Options {
pub client_id: u64,
pub guid: Arc<str>,
pub collection_id: Option<Arc<str>>,
pub offset_kind: OffsetKind,
pub skip_gc: bool,
pub auto_load: bool,
pub should_load: bool,
}Expand description
Configuration options of Doc instance.
Fields
client_id: u64Globally unique client identifier. This value must be unique across all active collaborating peers, otherwise a update collisions will happen, causing document store state to be corrupted.
Default value: randomly generated.
guid: Arc<str>A globally unique identifier for this document.
Default value: randomly generated UUID v4.
collection_id: Option<Arc<str>>Associate this document with a collection. This only plays a role if your provider has a concept of collection.
Default value: None.
offset_kind: OffsetKindHow to we count offsets and lengths used in text operations.
Default value: OffsetKind::Bytes.
skip_gc: boolDetermines if transactions commits should try to perform GC-ing of deleted items.
Default value: false.
auto_load: boolIf a subdocument, automatically load document. If this is a subdocument, remote peers will load the document as well automatically.
Default value: false.
should_load: boolWhether the document should be synced by the provider now. This is toggled to true when you call ydoc.load().
Default value: true.
Implementations
impl Options
impl Options
pub fn with_client_id(client_id: u64) -> Options
pub fn with_guid_and_client_id(guid: Arc<str>, client_id: u64) -> Options