Struct Signed
pub struct Signed<T>where
T: Copy,{ /* private fields */ }Expand description
Struct which recognizes signed integer values. This special case has been build for Yjs encoding
compatibility, which recognizes differences between 0 and -0, which is used in some
cases (eg. UIntOptRleDecoder).
Implementations
impl<T> Signed<T>where
T: Copy,
impl<T> Signed<T>where
T: Copy,
pub fn new(value: T, is_negative: bool) -> Signed<T>
pub fn is_positive(&self) -> bool
pub fn is_positive(&self) -> bool
Returns true is stored number is a positive value.
pub fn is_negative(&self) -> bool
pub fn is_negative(&self) -> bool
Returns true is stored number is a negative value (including -0 as a special case).
pub fn value(&self) -> T
pub fn value(&self) -> T
Returns a stored value.