Enum BranchID
pub enum BranchID {
Nested(ID),
Root(Arc<str>),
}Expand description
An unique logical identifier of a shared collection. Can be shared across document boundaries to reference to the same logical entity across different replicas of a document.
Variants
Implementations