Enum IndexScope
pub enum IndexScope {
Relative(ID),
Nested(ID),
Root(Arc<str>),
}Expand description
Struct describing context in which StickyIndex is placed. For items pointing inside of the shared typed sequence it’s always [StickyIndex::Relative] which refers to a block ID found under corresponding position.
In case when a containing collection is empty, there’s a no block ID that can be used as point of reference. In that case we store either a parent collection root type name or its branch ID instead (if collection is nested into another).
Using IDs guarantees that corresponding StickyIndex doesn’t shift under incoming concurrent updates.
Variants
Relative(ID)
StickyIndex is relative to a given block ID. This happens whenever we set StickyIndex somewhere inside the non-empty shared collection.
Nested(ID)
If a containing collection is a nested y-type, which is empty, this case allows us to identify that nested type.
Root(Arc<str>)
If a containing collection is a root-level y-type, which is empty, this case allows us to identify that nested type.
Implementations
impl IndexScope
impl IndexScope
pub fn from_branch(branch: BranchPtr) -> IndexScope