Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

merge_updates_v1

Function merge_updates_v1 

pub fn merge_updates_v1<I, B>(updates: I) -> Result<Vec<u8>, Error>
where I: IntoIterator<Item = B>, B: AsRef<[u8]>,
Merges a sequence of updates (encoded using lib0 v1 encoding) together, producing another update (also lib0 v1 encoded) in the result. Returned binary is a combination of all input updates, compressed.

Returns an error whenever any of the input updates couldn’t be decoded.