Struct MoveIter
pub struct MoveIter { /* private fields */ }Expand description
Block iterator which acknowledges context of move operation and iterates over blocks as they appear after move. It skips over the presence of move destination blocks.