Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

Subscription

Type Alias Subscription 

pub type Subscription = Arc<dyn Drop>;
Subscription handle returned by Observer::subscribe methods, which will unsubscribe corresponding callback when dropped.

If you need to send the Subscription handle to another thread, you may wish to enable the sync feature such that Subscription implements Send+Sync.

Aliased Type

pub struct Subscription { /* private fields */ }