Struct Hook
pub struct Hook<S> { /* private fields */ }Expand description
A descriptor used to reference to shared collections by their unique logical identifiers, which can be either Root-level collections or shared collections Nested into each other. It can be resolved from any shared reference using SharedRef::hook.
Implementations
impl<S> Hook<S>where
S: SharedRef,
impl<S> Hook<S>where
S: SharedRef,
pub fn get<T>(&self, txn: &T) -> Option<S>where
T: ReadTxn,
pub fn get<T>(&self, txn: &T) -> Option<S>where
T: ReadTxn,
Returns a reference to a shared collection current hook points to, if it exists and (in case of nested collections) has not been deleted.
Example
use yrs::{Hook, Doc, Map, MapRef, Nested, SharedRef, TextPrelim, TextRef, Transact, WriteTxn};
let doc = Doc::new();
let mut txn = doc.transact_mut();
let root = txn.get_or_insert_map("root"); // root-level collection
let nested = root.insert(&mut txn, "nested", TextPrelim::new("")); // nested collection
let root_hook: Hook<MapRef> = root.hook();
let nested_hook: Hook<TextRef> = nested.hook();
// hook can be used to retrieve collection reference as long as its alive
assert_eq!(nested_hook.get(&txn), Some(nested));
// after nested collection is deleted it can no longer be referenced
root.remove(&mut txn, "nested");
assert_eq!(nested_hook.get(&txn), None, "wtf");
// descriptors work also for root types
assert_eq!(root_hook.get(&txn), Some(root));pub fn into_nested(self) -> Option<Nested<S>>
pub fn into_nested(self) -> Option<Nested<S>>