Struct Snapshot
pub struct Snapshot {
pub delete_set: DeleteSet,
pub state_map: StateVector,
}Expand description
Snapshot describes a state of a document store at a given point in (logical) time. In practice it’s a combination of StateVector (a summary of all observed insert/update operations) and a DeleteSet (a summary of all observed deletions).
Fields
delete_set: DeleteSetCompressed information about all deleted blocks at current snapshot time.
state_map: StateVectorLogical clock describing a current snapshot time.
Implementations