Struct SubdocsEvent
pub struct SubdocsEvent { /* private fields */ }Expand description
Event used to communicate load requests from the underlying subdocuments.
Implementations
impl SubdocsEvent
impl SubdocsEvent
pub fn added(&self) -> SubdocsEventIter<'_> ⓘ
pub fn added(&self) -> SubdocsEventIter<'_> ⓘ
Returns an iterator over all sub-documents added to a current document within a scope of committed transaction.
pub fn removed(&self) -> SubdocsEventIter<'_> ⓘ
pub fn removed(&self) -> SubdocsEventIter<'_> ⓘ
Returns an iterator over all sub-documents removed from a current document within a scope of committed transaction.
pub fn loaded(&self) -> SubdocsEventIter<'_> ⓘ
pub fn loaded(&self) -> SubdocsEventIter<'_> ⓘ
Returns an iterator over all sub-documents living in a parent document, that have requested to be loaded within a scope of committed transaction.