Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

Transaction

Struct Transaction 

pub struct Transaction<'doc> { /* private fields */ }
A very lightweight read-only transaction. These transactions are guaranteed to not modify the contents of an underlying Doc and can be used to read it or for serialization purposes. For this reason it’s allowed to have a multiple active read-only transactions, but it’s not allowed to have any active read-write transactions at the same time.