Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

Update

Struct Update 

pub struct Update { /* private fields */ }
Update type which contains an information about all decoded blocks which are incoming from a remote peer. Since these blocks are not yet integrated into current document’s block store, they still may require repairing before doing so as they don’t contain full data about their relations.

Update is conceptually similar to a block store itself, however the work patters are different.

Implementations



impl Update

pub const EMPTY_V1: &'static [u8]

Binary containing an empty update, serialized via lib0 version 1 encoder.

pub const EMPTY_V2: &'static [u8]

Binary containing an empty update, serialized via lib0 version 2 encoder.

pub fn new() -> Update

pub fn is_empty(&self) -> bool

Check if current update is empty.

pub fn extends(&self, state_vector: &StateVector) -> bool

Check if current update has changes that add new information to a document with given state.

pub fn state_vector(&self) -> StateVector

Returns a state vector representing an upper bound of client clocks included by blocks stored in current update.

pub fn state_vector_lower(&self) -> StateVector

Returns a state vector representing a lower bound of items inserted by this update, grouped by their respective clients.

pub fn insertions(&self, include_deleted: bool) -> IdSet

Returns an insertion set associated with current update. It contains ids of all blocks inserted by this update. If include_deleted flag is set, result will include GC’ed blocks and ones that were inserted but softly deleted.

pub fn delete_set(&self) -> &DeleteSet

Returns a delete set associated with current update.

pub fn merge(&mut self, other: Update)

Merges another update into current one. Their blocks are deduplicated and reordered.

pub fn merge_updates<T>(block_stores: T) -> Update
where T: IntoIterator<Item = Update>,