Struct UpdateEvent
pub struct UpdateEvent {
pub update: Vec<u8>,
}Expand description
An update event passed to a callback subscribed with Doc::observe_update_v1/Doc::observe_update_v2.
Fields
update: Vec<u8>A binary which contains information about all inserted and deleted changes performed within the scope of its TransactionMut.