Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

XmlElementRef

Struct XmlElementRef 

pub struct XmlElementRef(/* private fields */);
XML element data type. It represents an XML node, which can contain key-value attributes (interpreted as strings) as well as other nested XML elements or rich text (represented by XmlTextRef type).

In terms of conflict resolution, XmlElementRef uses following rules:

  • Attribute updates use logical last-write-wins principle, meaning the past updates are automatically overridden and discarded by newer ones, while concurrent updates made by different peers are resolved into a single value using document id seniority to establish an order.
  • Child node insertion uses sequencing rules from other Yrs collections - elements are inserted using interleave-resistant algorithm, where order of concurrent inserts at the same index is established using peer’s document id seniority.

Implementations



impl XmlElementRef

pub fn try_tag(&self) -> Option<&Arc<str>>

A tag name of a current top-level XML node, eg. node <p></p> has “p” as it’s tag name.

pub fn tag(&self) -> &Arc<str>

A tag name of a current top-level XML node, eg. node <p></p> has “p” as it’s tag name.