Struct AwarenessUpdateSummary
pub struct AwarenessUpdateSummary {
pub added: Vec<u64>,
pub updated: Vec<u64>,
pub removed: Vec<u64>,
}Expand description
Summary of applying an AwarenessUpdate over Awareness::apply_update_summary method.
Fields
added: Vec<u64>New clients added as part of the update.
updated: Vec<u64>Existing clients that have been changed by the update.
removed: Vec<u64>Existing clients that have been removed by the update.
Implementations
impl AwarenessUpdateSummary
impl AwarenessUpdateSummary
pub fn all_changes(&self) -> Vec<u64>
pub fn all_changes(&self) -> Vec<u64>
Returns a collection of all clients that have been changed by the AwarenessUpdate.