Struct Event
pub struct Event { /* private fields */ }Expand description
Event type emitted by an Awareness struct.
Implementations
impl Event
impl Event
pub fn new(added: Vec<u64>, updated: Vec<u64>, removed: Vec<u64>) -> Event
pub fn summary(&self) -> &AwarenessUpdateSummary
pub fn added(&self) -> &[u64]
pub fn added(&self) -> &[u64]
Collection of new clients that have been added to an Awareness struct, that was not known
before. Actual client state can be accessed via awareness.clients().get(client_id).
pub fn updated(&self) -> &[u64]
pub fn updated(&self) -> &[u64]
Collection of new clients that have been updated within an Awareness struct since the last
update. Actual client state can be accessed via awareness.clients().get(client_id).
pub fn removed(&self) -> &[u64]
pub fn removed(&self) -> &[u64]
Collection of new clients that have been removed from Awareness struct since the last update.
pub fn all_changes(&self) -> Vec<u64>
pub fn all_changes(&self) -> Vec<u64>
Returns all the changed client IDs (added, updated and removed) combined.