Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

IndexedSequence

Trait IndexedSequence 

pub trait IndexedSequence: AsRef<Branch> {
    // Provided method
    fn sticky_index<T>(
        &self,
        txn: &T,
        index: u32,
        assoc: Assoc,
    ) -> Option<StickyIndex>
       where T: ReadTxn { ... }
}
Trait used to retrieve a StickyIndex corresponding to a given human-readable index. Unlike standard indexes StickyIndex enables to track the location inside of a shared y-types, even in the face of concurrent updates.

Provided Methods

fn sticky_index<T>( &self, txn: &T, index: u32, assoc: Assoc, ) -> Option<StickyIndex>
where T: ReadTxn,

Returns a StickyIndex equivalent to a human-readable index. Returns None if index is beyond the length of current sequence.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors