Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

SharedRef

Trait SharedRef 

pub trait SharedRef: From<BranchPtr> + AsRef<Branch> {
    // Provided method
    fn hook(&self) -> Hook<Self> { ... }
}
Common trait for shared collaborative collection types in Yrs.

Provided Methods

fn hook(&self) -> Hook<Self>

Returns a logical descriptor of a current shared collection.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors