Struct ArrayEvent
pub struct ArrayEvent { /* private fields */ }Expand description
Event generated by ArrayRef::observe method. Emitted during transaction commit phase.
Implementations
impl ArrayEvent
impl ArrayEvent
pub fn path(&self) -> VecDeque<PathSegment>
pub fn path(&self) -> VecDeque<PathSegment>
Returns a path from root type down to ArrayRef instance which emitted this event.
pub fn delta(&self, txn: &TransactionMut<'_>) -> &[Change]
pub fn delta(&self, txn: &TransactionMut<'_>) -> &[Change]
Returns summary of changes made over corresponding ArrayRef collection within a bounds of current transaction.
pub fn inserts(&self, txn: &TransactionMut<'_>) -> &HashSet<ID>
pub fn inserts(&self, txn: &TransactionMut<'_>) -> &HashSet<ID>
Returns a collection of block identifiers that have been added within a bounds of current transaction.
pub fn removes(&self, txn: &TransactionMut<'_>) -> &HashSet<ID>
pub fn removes(&self, txn: &TransactionMut<'_>) -> &HashSet<ID>
Returns a collection of block identifiers that have been removed within a bounds of current transaction.