Enum Change
pub enum Change {
Added(Vec<Out>),
Removed(u32),
Retain(u32),
}Expand description
A single change done over an array-component of shared data type.
Variants
Added(Vec<Out>)
Determines a change that resulted in adding a consecutive number of new elements:
- For Array it’s a range of inserted elements.
- For [XmlElement] it’s a range of inserted child XML nodes.
Removed(u32)
Determines a change that resulted in removing a consecutive range of existing elements, either XML child nodes for [XmlElement] or various elements stored in an Array.
Retain(u32)
Determines a number of consecutive unchanged elements. Used to recognize non-edited spaces between Change::Added and/or Change::Removed chunks.