Enum Delta
pub enum Delta<T = Out> {
Inserted(T, Option<Box<HashMap<Arc<str>, Any>>>),
Deleted(u32),
Retain(u32, Option<Box<HashMap<Arc<str>, Any>>>),
}Expand description
A single change done over a text-like types: Text or [XmlText].
Variants
Inserted(T, Option<Box<HashMap<Arc<str>, Any>>>)
Determines a change that resulted in insertion of a piece of text, which optionally could have been formatted with provided set of attributes.
Deleted(u32)
Determines a change that resulted in removing a consecutive range of characters.
Retain(u32, Option<Box<HashMap<Arc<str>, Any>>>)
Determines a number of consecutive unchanged characters. Used to recognize non-edited spaces between Delta::Inserted and/or Delta::Deleted chunks. Can contain an optional set of attributes, which have been used to format an existing piece of text.
Implementations