Enum PathSegment
pub enum PathSegment {
Key(Arc<str>),
Index(u32),
}Expand description
A single segment of a Path.
Variants
Key(Arc<str>)
Key segments are used to inform how to access child shared collections within a Map types.
Index(u32)
Index segments are used to inform how to access child shared collections within an Array or [XmlElement] types.