Struct MapEvent
pub struct MapEvent { /* private fields */ }Expand description
Event generated by [Map::observe] method. Emitted during transaction commit phase.
Implementations
impl MapEvent
impl MapEvent
pub fn path(&self) -> VecDeque<PathSegment>
pub fn path(&self) -> VecDeque<PathSegment>
Returns a path from root type down to Map instance which emitted this event.
pub fn keys(&self, txn: &TransactionMut<'_>) -> &HashMap<Arc<str>, EntryChange>
pub fn keys(&self, txn: &TransactionMut<'_>) -> &HashMap<Arc<str>, EntryChange>
Returns a summary of key-value changes made over corresponding Map collection within bounds of current transaction.