Struct Diff
pub struct Diff<T> {
pub insert: Out,
pub attributes: Option<Box<HashMap<Arc<str>, Any>>>,
pub ychange: Option<T>,
}Expand description
A representation of an uniformly-formatted chunk of rich context stored by TextRef or XmlTextRef. It contains a value (which could be a string, embedded object or another shared type) with optional formatting attributes wrapping around this chunk. It can also contain some custom data generated by caller as part of TextRef::diff callback.
Fields
insert: OutInserted chunk of data. It can be (usually) piece of text, but possibly also embedded value or another shared type.
attributes: Option<Box<HashMap<Arc<str>, Any>>>Optional formatting attributes wrapping inserted chunk of data.
ychange: Option<T>Custom user data attached to this chunk of data.
Implementations