Struct TextEvent
pub struct TextEvent { /* private fields */ }Expand description
Event generated by [Text::observe] method. Emitted during transaction commit phase.
Implementations
impl TextEvent
impl TextEvent
pub fn path(&self) -> VecDeque<PathSegment>
pub fn path(&self) -> VecDeque<PathSegment>
Returns a path from root type down to Text instance which emitted this event.
pub fn delta(&self, txn: &TransactionMut<'_>) -> &[Delta]
pub fn delta(&self, txn: &TransactionMut<'_>) -> &[Delta]
Returns a summary of text changes made over corresponding Text collection within bounds of current transaction.