Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

XmlElementPrelim

Struct XmlElementPrelim 

pub struct XmlElementPrelim {
    pub tag: Arc<str>,
    pub attributes: HashMap<Arc<str>, String>,
    pub children: Vec<XmlIn>,
}
A preliminary type that will be materialized into an XmlElementRef once it will be integrated into Yrs document.

Fields

tag: Arc<str>attributes: HashMap<Arc<str>, String>children: Vec<XmlIn>

Implementations



impl XmlElementPrelim

pub fn new<S, I>(tag: S, iter: I) -> XmlElementPrelim
where S: Into<Arc<str>>, I: IntoIterator<Item = XmlIn>,

pub fn empty<S>(tag: S) -> XmlElementPrelim
where S: Into<Arc<str>>,