Development Documentation (main branch) - For stable release docs, see docs.rs/eidetica

XmlEvent

Struct XmlEvent 

pub struct XmlEvent { /* private fields */ }
Event generated by [XmlElement::observe] method. Emitted during transaction commit phase.

Implementations



impl XmlEvent

pub fn children_changed(&self) -> bool

True if any child XML nodes have been changed within bounds of current transaction.

pub fn target(&self) -> &XmlOut

Returns a [XmlElement] instance which emitted this event.

pub fn path(&self) -> VecDeque<PathSegment>

Returns a path from root type down to [XmlElement] instance which emitted this event.

pub fn delta(&self, txn: &TransactionMut<'_>) -> &[Change]

Returns a summary of XML child nodes changed within corresponding [XmlElement] collection within bounds of current transaction.

pub fn added(&self, txn: &TransactionMut<'_>) -> &HashSet<ID>

Returns a collection of block identifiers that have been added within a bounds of current transaction.

pub fn deleted(&self, txn: &TransactionMut<'_>) -> &HashSet<ID>

Returns a collection of block identifiers that have been removed within a bounds of current transaction.

pub fn keys(&self, txn: &TransactionMut<'_>) -> &HashMap<Arc<str>, EntryChange>

Returns a summary of attribute changes made over corresponding [XmlElement] collection within bounds of current transaction.