Struct XmlFragmentPrelim
pub struct XmlFragmentPrelim(/* private fields */);Expand description
A preliminary type that will be materialized into an XmlFragmentRef once it will be integrated into Yrs document.
Implementations
impl XmlFragmentPrelim
impl XmlFragmentPrelim
pub fn new<I, T>(iter: I) -> XmlFragmentPrelimwhere
I: IntoIterator<Item = XmlIn>,