Struct XmlTextEvent
pub struct XmlTextEvent { /* private fields */ }Expand description
Event generated by [XmlText::observe] method. Emitted during transaction commit phase.
Implementations
impl XmlTextEvent
impl XmlTextEvent
pub fn target(&self) -> &XmlTextRef
pub fn target(&self) -> &XmlTextRef
Returns a [XmlText] instance which emitted this event.
pub fn path(&self) -> VecDeque<PathSegment>
pub fn path(&self) -> VecDeque<PathSegment>
Returns a path from root type down to [XmlText] instance which emitted this event.
pub fn delta(&self, txn: &TransactionMut<'_>) -> &[Delta]
pub fn delta(&self, txn: &TransactionMut<'_>) -> &[Delta]
Returns a summary of text changes made over corresponding [XmlText] collection within bounds of current transaction.
pub fn keys(&self, txn: &TransactionMut<'_>) -> &HashMap<Arc<str>, EntryChange>
pub fn keys(&self, txn: &TransactionMut<'_>) -> &HashMap<Arc<str>, EntryChange>
Returns a summary of attribute changes made over corresponding [XmlText] collection within bounds of current transaction.