Struct Event
pub struct Event<M> { /* private fields */ }Implementations
impl<M> Event<M>
impl<M> Event<M>
pub fn meta(&self) -> &M
pub fn meta_mut(&mut self) -> &mut M
pub fn has_changed<T>(&self, target: &T) -> bool
pub fn has_changed<T>(&self, target: &T) -> bool
Checks if given shared collection has changed in the scope of currently notified update.
pub fn origin(&self) -> Option<&Origin>
pub fn origin(&self) -> Option<&Origin>
Returns a transaction origin related to this update notification.
pub fn kind(&self) -> EventKind
pub fn kind(&self) -> EventKind
Returns an enum informing if current update is result of undo or redo operation.
pub fn changed_parent_types(&self) -> &[BranchPtr]
pub fn changed_parent_types(&self) -> &[BranchPtr]
Returns info about all changed shared collections.