Struct StackItem
pub struct StackItem<T> {
pub meta: T,
/* private fields */
}Expand description
A unit of work for the UndoManager. It contains a compressed information about all updates and deletions tracked by a corresponding undo manager. Whenever an [UndoManger::undo] or UndoManager::redo methods are called a last StackItem is being used to modify a state of the document.
Stack items are stored internally by undo manager and created automatically whenever a new update from tracked shared type and transaction of tracked origin has been committed within a threshold specified by Options::capture_timeout_millis time window since the previous stack item creation. They can also be created explicitly by calling UndoManager::reset, which marks the end of the last stack item batch.
Fields
meta: TA custom user metadata that can be attached to a particular StackItem. It can be used to carry over the additional information (such as ie. user cursor position) between undo/redo operations.
Implementations
impl<M> StackItem<M>
impl<M> StackItem<M>
pub fn with_meta( deletions: DeleteSet, insertions: DeleteSet, meta: M, ) -> StackItem<M>
pub fn deletions(&self) -> &DeleteSet
pub fn deletions(&self) -> &DeleteSet
A set of identifiers of element deleted at part of the timeframe current StackItem is responsible for.
pub fn insertions(&self) -> &DeleteSet
pub fn insertions(&self) -> &DeleteSet
A set of identifiers of element inserted at part of the timeframe current StackItem is responsible for.