pub fn can_delegate_with_bounds(
delegating_permission: &Permission,
bounds: &PermissionBounds,
) -> boolExpand description
Check if a delegating key has sufficient permission to set the given bounds
A key can only delegate permissions that are at or below its own level.
Arguments
delegating_permission- Permission level of the key setting up delegationbounds- The permission bounds being configured
Returns
true if the delegating key can set these bounds, false otherwise