pub struct AuthKey {
pub name: Option<String>,
/* private fields */
}Expand description
Authentication key configuration stored in _settings.auth
Keys are indexed by pubkey in AuthSettings. The name field is optional metadata that can be used as a hint in signatures.
Fields
name: Option<String>Optional human-readable name for this key Multiple keys can share the same name (aliases)
Implementations
Sourceimpl AuthKey
impl AuthKey
Sourcepub fn new(
name: Option<&str>,
permissions: Permission,
status: KeyStatus,
) -> Self
pub fn new( name: Option<&str>, permissions: Permission, status: KeyStatus, ) -> Self
Create a new AuthKey with validation
Arguments
name- Optional human-readable name for this keypermissions- Permission level for this keystatus- Current status of the key
Examples
use eidetica::auth::types::{AuthKey, Permission, KeyStatus};
let key = AuthKey::new(
Some("alice_laptop"),
Permission::Write(10),
KeyStatus::Active
);Sourcepub fn active(name: Option<&str>, permissions: Permission) -> Self
pub fn active(name: Option<&str>, permissions: Permission) -> Self
Sourcepub fn permissions(&self) -> &Permission
pub fn permissions(&self) -> &Permission
Get the permissions
Sourcepub fn set_status(&mut self, status: KeyStatus)
pub fn set_status(&mut self, status: KeyStatus)
Set the status (e.g., for revocation)
Sourcepub fn set_permissions(&mut self, permissions: Permission)
pub fn set_permissions(&mut self, permissions: Permission)
Set the permissions (e.g., for updates)