#[non_exhaustive]pub enum BackendError {
Show 19 variants
EntryNotFound {
id: ID,
},
EntryValidationFailed {
entry_id: ID,
reason: String,
},
VerificationStatusNotFound {
id: ID,
},
EntryNotInTree {
entry_id: ID,
tree_id: ID,
},
EntryNotInSubtree {
entry_id: ID,
tree_id: ID,
subtree: String,
},
CycleDetected {
entry_id: ID,
},
NoCommonAncestor {
entry_ids: Vec<ID>,
},
EmptyEntryList {
operation: String,
},
HeightCalculationCorruption {
reason: String,
},
PrivateKeyNotFound {
key_name: String,
},
SerializationFailed {
source: Error,
},
DeserializationFailed {
source: Error,
},
FileIo {
source: Error,
},
CrdtCacheError {
reason: String,
},
TreeIntegrityViolation {
reason: String,
},
InvalidTreeReference {
tree_id: String,
},
StateInconsistency {
reason: String,
},
CacheError {
reason: String,
},
SqlxError {
reason: String,
source: Option<Error>,
},
}Expand description
Errors that can occur during database operations.
Stability
- New variants may be added in minor versions (enum is
#[non_exhaustive]) - Existing variants will not be removed in minor versions
- Field additions/changes require a major version bump
- Helper methods like
is_*()provide stable APIs
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EntryNotFound
Entry not found by ID.
EntryValidationFailed
Entry failed structural validation.
Fields
VerificationStatusNotFound
Verification status not found for entry.
EntryNotInTree
Entry is not part of the specified tree.
EntryNotInSubtree
Entry is not part of the specified subtree.
Fields
CycleDetected
Cycle detected in DAG structure.
NoCommonAncestor
No common ancestor found for given entries.
EmptyEntryList
Empty entry list provided where non-empty list required.
HeightCalculationCorruption
Data corruption detected during height calculation.
PrivateKeyNotFound
Private key not found.
SerializationFailed
Serialization failed.
DeserializationFailed
Deserialization failed.
FileIo
File I/O error.
CrdtCacheError
CRDT cache operation failed.
TreeIntegrityViolation
Database integrity violation detected.
InvalidTreeReference
Invalid tree reference or tree ID.
StateInconsistency
Database state inconsistency detected.
CacheError
Cache miss or cache corruption.
SqlxError
SQL database error (sqlx).
Implementations
Sourceimpl BackendError
impl BackendError
Sourcepub fn is_not_found(&self) -> bool
pub fn is_not_found(&self) -> bool
Check if this error indicates a resource was not found.
Sourcepub fn is_integrity_error(&self) -> bool
pub fn is_integrity_error(&self) -> bool
Check if this error indicates a data integrity issue.
Sourcepub fn is_io_error(&self) -> bool
pub fn is_io_error(&self) -> bool
Check if this error is related to I/O operations.
Sourcepub fn is_sql_error(&self) -> bool
pub fn is_sql_error(&self) -> bool
Check if this error is related to SQL database operations.
Sourcepub fn is_cache_error(&self) -> bool
pub fn is_cache_error(&self) -> bool
Check if this error is related to cache operations.
Sourcepub fn is_logical_error(&self) -> bool
pub fn is_logical_error(&self) -> bool
Check if this error indicates a logical inconsistency.