#[non_exhaustive]pub enum EntryError {
ValidationFailed {
reason: String,
},
SerializationFailed {
context: String,
},
InvalidStructure {
reason: String,
},
InvalidIndexData {
reason: String,
},
}Expand description
Errors that can occur during entry operations.
Stability
- New variants may be added in minor versions (enum is
#[non_exhaustive]) - Existing variants will not be removed in minor versions
- Field additions/changes require a major version bump
- Helper methods like
is_*()provide stable APIs
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ValidationFailed
Entry validation failed during creation or processing
SerializationFailed
Entry serialization failed
InvalidStructure
Entry structure is invalid
InvalidIndexData
Invalid _index subtree data during entry building
Implementations
Sourceimpl EntryError
impl EntryError
Sourcepub fn is_validation_error(&self) -> bool
pub fn is_validation_error(&self) -> bool
Check if this error is validation-related.
Sourcepub fn is_serialization_error(&self) -> bool
pub fn is_serialization_error(&self) -> bool
Check if this error is serialization-related.