pub struct ValueEditor<'a> { /* private fields */ }Expand description
An editor for a Value obtained from a DocStore.
This provides a mutable lens into a value, allowing modifications to be staged and then saved back to the DocStore.
Implementations
Sourceimpl<'a> ValueEditor<'a>
impl<'a> ValueEditor<'a>
pub fn new<K>(kv_store: &'a DocStore, keys: K) -> Self
Sourcepub async fn get(&self) -> Result<Value>
pub async fn get(&self) -> Result<Value>
Uses the stored keys to traverse the nested data structure and retrieve the value.
This method starts from the fully merged view of the DocStore’s subtree (local
Transaction changes layered on top of backend state) and navigates using the path
specified by self.keys. If self.keys is empty, it retrieves the root
of the DocStore’s subtree.
Returns Error::NotFound if any part of the path does not exist, or if the
final value is a tombstone (Value::Deleted).
Returns Error::Io with ErrorKind::InvalidData if a non-map value is encountered
during path traversal where a map was expected.
Sourcepub async fn set(&self, value: Value) -> Result<()>
pub async fn set(&self, value: Value) -> Result<()>
Sets a Value at the path specified by self.keys within the DocStore’s Transaction.
This method modifies the local data associated with the Transaction. The changes
are not persisted to the backend until Transaction::commit() is called.
If the path specified by self.keys does not exist, it will be created.
Intermediate non-map values in the path will be overwritten by maps as needed.
If self.keys is empty (editor points to root), the provided value must
be a Value::Doc.
Returns Error::InvalidOperation if setting the root and value is not a node.
Sourcepub async fn get_value(&self, key: impl AsRef<str>) -> Result<Value>
pub async fn get_value(&self, key: impl AsRef<str>) -> Result<Value>
Returns a nested value by appending key to the current editor’s path.
This is a convenience method that uses self.get() to find the map at the current
editor’s path, and then retrieves key from that map.
Sourcepub fn get_value_mut(&self, key: impl Into<String>) -> ValueEditor<'a>
pub fn get_value_mut(&self, key: impl Into<String>) -> ValueEditor<'a>
Constructs a new ValueEditor for a path one level deeper.
The new editor’s path will be self.keys with key appended.
Sourcepub async fn delete_self(&self) -> Result<()>
pub async fn delete_self(&self) -> Result<()>
Marks the value at the editor’s current path as deleted.
This is achieved by setting its value to Value::Deleted.
The change is staged in the Transaction and needs to be committed.
Sourcepub async fn delete_child(&self, key: impl Into<String>) -> Result<()>
pub async fn delete_child(&self, key: impl Into<String>) -> Result<()>
Marks the value at the specified child key (relative to the editor’s current path) as deleted.
This is achieved by setting its value to Value::Deleted.
The change is staged in the Transaction and needs to be committed.
If the editor points to the root (empty path), this will delete the top-level key.