pub enum SyncCommand {
SendEntries {
peer: PeerId,
entries: Vec<Entry>,
},
SyncWithPeer {
peer: PeerId,
},
Shutdown,
AddTransport {
name: String,
transport: Box<dyn SyncTransport>,
response: Sender<Result<()>>,
},
StartServer {
name: Option<String>,
response: Sender<Result<()>>,
},
StopServer {
name: Option<String>,
response: Sender<Result<()>>,
},
GetServerAddress {
name: String,
response: Sender<Result<String>>,
},
GetAllServerAddresses {
response: Sender<Result<Vec<(String, String)>>>,
},
ConnectToPeer {
address: Address,
response: Sender<Result<PublicKey>>,
},
SendRequest {
address: Address,
request: Box<SyncRequest>,
response: Sender<Result<SyncResponse>>,
},
Flush {
response: Sender<Result<()>>,
},
}Expand description
Commands that can be sent to the background sync engine
Variants
SendEntries
Send entries to a specific peer
SyncWithPeer
Trigger immediate sync with a peer
Shutdown
Shutdown the background engine
AddTransport
Add a named transport to the transport manager
StartServer
Start the sync server on specified or all transports
Fields
StopServer
Stop the sync server on specified or all transports
Fields
GetServerAddress
Get the server’s listening address for a specific transport
GetAllServerAddresses
Get all server addresses for running servers
ConnectToPeer
Connect to a peer and perform handshake
SendRequest
Send a sync request and get response
Flush
Flush: process all queued entries and retry queue, then respond.