pub struct IrohTransportConfig {
pub secret_key_hex: Option<String>,
pub relay_mode: RelayModeSetting,
}Expand description
Persistable configuration for the Iroh transport.
This configuration is stored in the _sync database’s transport_configs
subtree and is automatically loaded when enable_iroh_transport() is called.
The most important field is secret_key_hex, which stores the node’s
cryptographic identity. When this is persisted, the node will have the
same address across restarts.
Example
use eidetica::sync::transports::iroh::IrohTransportConfig;
// Create a default config (secret key will be generated on first use)
let config = IrohTransportConfig::default();
// Or create with specific settings
let config = IrohTransportConfig {
relay_mode: RelayModeSetting::Disabled,
..Default::default()
};Fields
secret_key_hex: Option<String>Secret key bytes (hex encoded for JSON storage).
When None, a new secret key will be generated on first use
and stored back to the config. Once set, this ensures the node
maintains the same identity (and thus address) across restarts.
relay_mode: RelayModeSettingRelay mode setting for NAT traversal.
Implementations
Sourceimpl IrohTransportConfig
impl IrohTransportConfig
Sourcepub fn get_or_create_secret_key(&mut self) -> SecretKey
pub fn get_or_create_secret_key(&mut self) -> SecretKey
Get the secret key from config, or generate a new one.
If a secret key is already stored in the config, it will be decoded and returned. Otherwise, a new random secret key is generated, stored in the config (as hex), and returned.
This method mutates the config to store the newly generated key, so the caller should persist the config after calling this.
Sourcepub fn has_secret_key(&self) -> bool
pub fn has_secret_key(&self) -> bool
Check if a secret key has been set in this config.