Enum Any
pub enum Any {
Null,
Undefined,
Bool(bool),
Number(f64),
BigInt(i64),
String(Arc<str>),
Buffer(Arc<[u8]>),
Array(Arc<[Any]>),
Map(Arc<HashMap<String, Any>>),
}Expand description
Any is an enum with a potentially associated value that is used to represent JSON values and supports efficient encoding of those values.
Variants
Null
Undefined
Bool(bool)
Number(f64)
BigInt(i64)
String(Arc<str>)
Buffer(Arc<[u8]>)
Array(Arc<[Any]>)
Map(Arc<HashMap<String, Any>>)
Implementations
impl Any
impl Any
pub fn cast<T>(self) -> Result<T, Any>
pub fn decode<R>(decoder: &mut R) -> Result<Any, Error>where
R: Read,
pub fn encode<W>(&self, encoder: &mut W)where
W: Write,
pub fn from_json(src: &str) -> Result<Any, Error>
pub fn to_json(&self, buf: &mut String)
pub fn try_iter(&self) -> Option<AnyIter<'_>>
pub fn try_iter(&self) -> Option<AnyIter<'_>>
Returns an iterator over an inner values of an array or a map, current reference represents.
pub fn try_into_iter(self) -> Option<AnyIntoIter>