Struct DeleteSet
pub struct DeleteSet(/* private fields */);Expand description
DeleteSet contains information about all blocks (described by clock ranges) that have been subjected to delete process.
Implementations
impl DeleteSet
impl DeleteSet
pub fn insert(&mut self, id: ID, len: u32)
pub fn insert(&mut self, id: ID, len: u32)
Inserts an information about delete block (identified by id and having a specified length)
inside of a current delete set.
pub fn is_deleted(&self, id: &ID) -> bool
pub fn is_deleted(&self, id: &ID) -> bool
Checks if given block id is considered deleted from the perspective of current delete set.
pub fn iter(&self) -> Iter<'_, u64, IdRange>
pub fn iter(&self) -> Iter<'_, u64, IdRange>
Returns an iterator over all client-range pairs registered in this delete set.
pub fn merge(&mut self, other: DeleteSet)
pub fn merge(&mut self, other: DeleteSet)
Merges another delete set into a current one, combining their information about deleted clock ranges.
pub fn squash(&mut self)
pub fn squash(&mut self)
Squashes the contents of a current delete set. This operation means, that in case when delete set contains any overlapping ranges within, they will be squashed together to optimize the space and make future encoding more compact.
pub fn range(&self, client_id: &u64) -> Option<&IdRange>