A path describing nesting structure between shared collections containing each other. It’s a
collection of segments which refer to either index (in case of Array or [XmlElement]) or
string key (in case of Map) where successor shared collection can be found within subsequent
parent types.