Struct XmlElementPrelim
pub struct XmlElementPrelim {
pub tag: Arc<str>,
pub attributes: HashMap<Arc<str>, String>,
pub children: Vec<XmlIn>,
}Expand description
A preliminary type that will be materialized into an XmlElementRef once it will be integrated into Yrs document.
Fields
tag: Arc<str>attributes: HashMap<Arc<str>, String>children: Vec<XmlIn>Implementations
impl XmlElementPrelim
impl XmlElementPrelim
pub fn new<S, I>(tag: S, iter: I) -> XmlElementPrelim
pub fn empty<S>(tag: S) -> XmlElementPrelim