Struct Options
pub struct Options<M> {
pub capture_timeout_millis: u64,
pub tracked_origins: HashSet<Origin>,
pub capture_transaction: Option<Arc<dyn Fn(&TransactionMut<'_>) -> bool + Send + Sync>>,
pub timestamp: Arc<dyn Clock>,
pub init_undo_stack: Vec<StackItem<M>>,
pub init_redo_stack: Vec<StackItem<M>>,
}Expand description
Set of options used to configure UndoManager.
Fields
capture_timeout_millis: u64Undo-/redo-able updates are grouped together in time-constrained snapshots. This field determines the period of time, every snapshot will be automatically made in.
tracked_origins: HashSet<Origin>List of origins tracked by corresponding UndoManager. If provided, it will track only updates made within transactions of specific origin. If not provided, it will track only updates made within transaction with no origin defined.
capture_transaction: Option<Arc<dyn Fn(&TransactionMut<'_>) -> bool + Send + Sync>>Custom logic decider, that along with [tracked_origins] can be used to determine if transaction changes should be captured or not.
timestamp: Arc<dyn Clock>Custom clock function, that can be used to generate timestamps used by Options::capture_timeout_millis.
init_undo_stack: Vec<StackItem<M>>Initial undo stack that can be pre-filled with some operations that can be undone.
init_redo_stack: Vec<StackItem<M>>Initial redo stack that can be pre-filled with some operations that can be redone.